# encoding: utf-8

# *****************************************************************************
#
# (c) Copyright 2022 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors(Micro Focus) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional warranty.
# Micro Focus shall not be liable for technical or editorial errors or
# omissions contained herein.
# The information contained herein is subject to change without notice.
#
# ******************************************************************************
# File:        clients/umc.rb
# Module:      Installation
# Summary:     Main file
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#              Srinidhi B <Srinidhi.BS@microfocus.com>
#

module Yast
  class UmcClient < Client
    def main
      Yast.import "UI"

      textdomain "umc"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("UMC module started")

      Yast.import "Progress"
      Yast.import "Report"
      Yast.import "Summary"
      Yast.import "NovellAddonInstall"
      Yast.import "CommandLine"
      Yast.include self, "umc/wizards.rb"

      @cmdline_description = {
        "id"         => "umc",
        # Command line help text for the XUmc module
        "help"       => _(
          "Configuration of UMC"
        ),
        "guihandler" => fun_ref(method(:UmcSequence), "any ()"),
        "initialize" => fun_ref(Umc.method(:Read), "boolean ()"),
        "finish"     => fun_ref(Umc.method(:Write), "boolean ()"),
        "actions" =>
          # FIXME TODO: fill the functionality description here
          {},
        "options" =>
          # FIXME TODO: fill the option descriptions here
          {},
        "mapping" =>
          # FIXME TODO: fill the mappings of actions and options here
          {}
      }

      # is this proposal or not?
      @propose = false
      @args = WFM.Args
      if Ops.greater_than(Builtins.size(@args), 0)
        if Ops.is_path?(WFM.Args(0)) && WFM.Args(0) == path(".propose")
          Builtins.y2milestone("Using PROPOSE mode")
          @propose = true
        end
      end

      # main ui function
      @ret = nil

      if @propose
        if Ops.get(NovellAddonInstall.products_to_configure, "umc", true)
          @ret = UmcAutoSequence()
        else
          @ret = :next
        end
      else
        @ret = CommandLine.Run(@cmdline_description)
      end
      Builtins.y2debug("ret=%1", @ret)

      # Finish
      Builtins.y2milestone("UMC module finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::UmcClient.new.main
