# encoding: utf-8

# *****************************************************************************
#
# (c) Copyright 2022 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors(Micro Focus) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional warranty.
# Micro Focus shall not be liable for technical or editorial errors or
# omissions contained herein.
# The information contained herein is subject to change without notice.
#
# ******************************************************************************
# File:        clients/umc_auto.rb
# Module:      Installation
# Summary:     Client for autoinstallation
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#              Srinidhi B <Srinidhi.BS@microfocus.com>
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

module Yast
  class UmcAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "umc"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("UMC auto started")

      Yast.import "Umc"
      Yast.include self, "umc/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(NovellLum.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        Umc.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        @ret = UmcAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = Umc.Import(@param)
      # Return actual state
      elsif @func == "Export"
        Umc.Read if Umc.Settings == nil || Umc.Settings == {}
        Umc.auto_clone = true
        @ret = Umc.Export
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Umc.Read
        Progress.set(@progress_orig)
      # Write given settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Umc.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        Umc.globals_configured = true
        @ret = Umc.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        Umc.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("UMC auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::UmcAutoClient.new.main
