# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	    clients/umc_proposal.rb
# Package:	Configuration of UMC
# Summary:	Proposal function dispatcher.
# Authors:  Gaurav Kumar <gaurav.kumar4@microfocus.com>
#           Srinidhi B <Srinidhi.BS@microfocus.com>
#
# Proposal function dispatcher for umc configuration.
module Yast
  class UmcProposalClient < Client
    def main

      textdomain "umc"

      Yast.import "Umc"
      Yast.import "Progress"
      Yast.import "Mode"
      Yast.import "NovellLDAP"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Umc proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !Umc.proposal_valid
          Umc.proposal_valid = true
          @progress_orig = Progress.set(false)
          Umc.Read
          Progress.set(@progress_orig)
        end
        @sum = Umc.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("umc", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }

        if Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          ) == "" &&
            Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
            Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_USERNAME", "") == ""
          Ops.set(@ret, "errors", true)
        end
      # run the module
      elsif @func == "AskUser"
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("UMC proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "umc--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "umc", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "umc--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "umc", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = Umc.Export
          @seq = Convert.to_symbol(
            WFM.CallFunction("umc", [path(".propose")])
          )
          Umc.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("microfocus-umc") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("umc")
        Builtins.y2milestone(
          "Proposal:IsSelected:umc: %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Umc in proposals
            "rich_text_title" => _(
              "Unified Management Console"
            ),
            # Menu title for Umc in proposals
            "menu_title"      => _(
              "Unified Management Console"
            ),
            "id"              => "umc"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        Umc.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Umc proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::UmcProposalClient.new.main
