# encoding: utf-8

# *****************************************************************************
# Copyright 2023 Open Text.
#
# The only warranties for products and services of Open Text and its
# affiliates and licensors (“Open Text”) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional
# warranty. Open Text shall not be liable for technical or editorial
# errors or omissions contained herein. The information contained herein
# is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains
# confidential information and a valid license is required for possession,
# use or copying. If this work is provided to the U.S. Government,
# consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items
# are licensed to the U.S. Government under vendor's standard commercial
# license.
# *****************************************************************************
# *****************************************************************************
#
# (c) Copyright 2022 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors(Micro Focus) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional warranty.
# Micro Focus shall not be liable for technical or editorial errors or
# omissions contained herein.
# The information contained herein is subject to change without notice.
#
# ******************************************************************************
# File:        include/umc/dialogs.rb
# Module:      Installation
# Summary:     Dialogs definitions
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#              Srinidhi B <Srinidhi.BS@microfocus.com>
#

module Yast
  module UmcDialogsInclude
    def initialize_umc_dialogs(include_target)
      Yast.import "UI"

      textdomain "umc"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Umc"
      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "DNS"

      Yast.include include_target, "umc/complex.rb"
      Yast.include include_target, "umc/helps.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      @useXad = Umc.useXad

      Builtins.y2milestone(
        "oes-umc.PromptIfNeededForEdirAdminPassword:use xad:%1",
        @useXad
      )

      if @useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end

      @useXad
    end

    #UMC dialog
    def UmcDialog
      openPort = false
      dbPassword = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_PASSWORD", "")
      dbHostName = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_HOSTNAME", "")
      dbUserName = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_USERNAME", "")
      dbPort = Ops.get_string(Umc.Settings, "CONFIG_UMC_DB_PORT", "")
      edirApiPort = Ops.get_string(Umc.Settings, "CONFIG_UMC_EDIRAPI_PORT", "")

      if Ops.get_string(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "") == "yes"
        openPort = true
      end

      caption = _("OES Unified Management Console (UMC) Configuration")
      contents = VBox(
        VSpacing(0.5),
          Frame(
            _("Database Details"),
            VBox(
              VSpacing(0.25),
              HBox(
                TextEntry(
                  Id(:dbhostname),
                  Opt(:notify),
                  _("Hostname"),
                  dbHostName
                )
              ),
              HBox(
                HWeight(50,
                TextEntry(
                  Id(:dbport),
                  _("Port"),
                  dbPort
                )),
                HSpacing(1),
                HWeight(50,
                TextEntry(
                  Id(:dbusername),
                  _("Username"),
                  dbUserName
                ))
              ),
              HBox(
                HWeight(50,
                Password(
                  Id(:dbpassword),
                  _("Password"),
                  dbPassword
                )),
                HSpacing(1),
                HWeight(50,
                Password(
                  Id(:verifydbpassword),
                  _("Verify Password"),
                  ""
                ))
              ),
              Left(
                CheckBox(
                  Id(:openport),
                  Opt(:notify),
                  _("Open Port in Firewall"),
                  openPort
                )
              ),
              Left(
                HBox(
                  Label(_("Validate Database Connection")),
                  HBox(Label(""), PushButton(Id(:testDBConnection), _("Validate")))
                )
              )
            )
          ),
          HBox(
            TextEntry(
              Id(:edirport),
              Opt(:notify),
              _("eDirectory API Port"),
              edirApiPort
            )
          ),
          VStretch()
        )

      PromptIfNeededForEdirAdminPassword()
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "umc_config", ""),
        Label.BackButton,
        Label.NextButton
      )

      if dbHostName == "localhost" || dbHostName == NovellUtils.GetDNSname || dbHostName == NovellUtils.GetHostname
        UI.ChangeWidget(Id(:testDBConnection), :Enabled, false)
        UI.ChangeWidget(Id(:openport), :Enabled, true)
      else
        UI.ChangeWidget(Id(:testDBConnection), :Enabled, true)
        UI.ChangeWidget(Id(:openport), :Enabled, false)
      end

      if Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "no" &&
        dbHostName == NovellUtils.GetDNSname
        UI.ChangeWidget(Id(:verifydbpassword), :Enabled, true)
        UI.ChangeWidget(Id(:testDBConnection), :Enabled, false)
        UI.ChangeWidget(Id(:openport), :Enabled, true)
      elsif Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "yes" ||
        dbHostName == Umc.existing_db_hostname
        UI.ChangeWidget(Id(:testDBConnection), :Enabled, true)
        UI.ChangeWidget(Id(:verifydbpassword), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        #read all values
        dbHostName = Convert.to_string(UI.QueryWidget(Id(:dbhostname), :Value))
        dbUserName = Convert.to_string(UI.QueryWidget(Id(:dbusername), :Value))
        dbPort = Convert.to_string(UI.QueryWidget(Id(:dbport), :Value))
        dbPassword = Convert.to_string(UI.QueryWidget(Id(:dbpassword), :Value))
        verifyPass = Convert.to_string(UI.QueryWidget(Id(:verifydbpassword), :Value))
        edirApiPort = Convert.to_string(UI.QueryWidget(Id(:edirport), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :dbhostname
          if dbHostName != Umc.existing_db_hostname && dbHostName == NovellUtils.GetDNSname
            UI.ChangeWidget(Id(:verifydbpassword), :Enabled, true)
            UI.ChangeWidget(Id(:openport), :Enabled, true)
          else
            UI.ChangeWidget(Id(:verifydbpassword), :Enabled, false)
            UI.ChangeWidget(Id(:openport), :Enabled, false)
          end

          #Disable/Enable Validate button on the value of db hostname, for remote db enable validate
          #and disbale for local db
          if isLocalServer?(dbHostName)
            UI.ChangeWidget(Id(:testDBConnection), :Enabled, false)
          else
            UI.ChangeWidget(Id(:testDBConnection), :Enabled, true)
          end
        elsif ret == :testDBConnection
          if !ValidateDatabaseDetails(dbHostName, dbUserName, dbPort, dbPassword)
            next
          else
            Report.Message(
              Builtins.sformat(
                _("Successfully connected to the database.")
              )
            )
          end
        elsif ret == :next
          #Validate Username
          if !ValidateDBUsername(dbUserName)
            next
          end

          #Validate edir api port
          if !ValidateEdirApiPort(edirApiPort)
            next
          end

          #Validate Password
          if Ops.get_string(Umc.Settings, "SERVICE_CONFIGURED", "") == "no" &&
            dbHostName == NovellUtils.GetDNSname
            if !NovellValidators.ValidatePasswords(dbPassword, verifyPass)
              UI.ChangeWidget(Id(:dbpassword), :Value, "")
              UI.ChangeWidget(Id(:verifydbpassword), :Value, "")
              UI.SetFocus(Id(:dbpassword))
              next
            end
          end

          #Validate Dtabase Details
          if !ValidateDatabaseDetails(dbHostName, dbUserName, dbPort, dbPassword)
            next
          end

          #nslooup for db hostname
          hostName = ""
          hostName = ValidateDbHostname(dbHostName)

          if hostName != ""
            dbHostName = hostName
            Builtins.y2milestone("DB hostname value after ValidateDbHostname is %1", dbHostName)
          elsif hostName == "" && isRemoteServer?(dbHostName)
            Popup.Message(_("Invalid Hostname. nslookup failed for the specified Hostname."))
            Builtins.y2milestone("nslookup failed for database hostname")
            next
          end

          Ops.set(Umc.Settings, "CONFIG_UMC_DB_HOSTNAME", dbHostName)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_PORT", dbPort)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_USERNAME", dbUserName)
          Ops.set(Umc.Settings, "CONFIG_UMC_DB_PASSWORD", dbPassword)
          Ops.set(Umc.Settings, "CONFIG_UMC_EDIRAPI_PORT", edirApiPort)

          if Convert.to_boolean(UI.QueryWidget(Id(:openport), :Value))
            Ops.set(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "yes")
          else
            Ops.set(Umc.Settings, "CONFIG_UMC_OPEN_DB_PORT", "no")
          end
          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    def ValidateDBUsername(dbUserName)
      if Builtins.contains(dbUserName, ":") || Builtins.contains(dbUserName, "/")
        Popup.Message(_('Invalid Username. ":" and "/" are not allowed.'))
        return false
      end
      return true
    end
    def ValidateDatabaseDetails(dbHostName, dbUserName, dbPort, dbPassword)
      if dbHostName == "" || dbUserName == "" || dbPort == "" || dbPassword  == ""
        Popup.Message(_("Provide all the Database Details."))
        return false
      else
        if isRemoteServer?(dbHostName) || dbHostName == Umc.existing_db_hostname
          if !Umc.ValidateDB(dbHostName, dbUserName, dbPassword, dbPort)
            return false
          end
        end
      end
      return true
    end

    def ValidateEdirApiPort(edirApiPort)
      if edirApiPort == "" || edirApiPort == nil
        Popup.Message(_("Provide eDirectory API Port."))
        return false
      end
      return true
    end

    def ValidateDbHostname(dbHostName)
      if isRemoteServer?(dbHostName)
        hostnameLookup = Convert.to_map(
          SCR.Execute(
            path(".target.bash_output"),
            Builtins.sformat("nslookup %1", dbHostName)
          )
        )

        Builtins.y2milestone(
          "Retmap for nslookup %1 is %2",
          dbHostName,
          hostnameLookup
        )

        if Ops.get_integer(hostnameLookup, "exit", -1) == 0
          getResolvedHost = Builtins.sformat("nslookup %1 | grep Name: | cut -d ':' -f2 | head -n 1", dbHostName)
          Builtins.y2milestone(
            "Executing %1",
            getResolvedHost
          )
          rmap = Convert.to_map(
            SCR.Execute(
              path(".target.bash_output"),
              getResolvedHost
            )
          )
          Builtins.y2milestone(
            "Retmap for %1 is %2",
            getResolvedHost,
            rmap
          )
          if Ops.get_integer(rmap, "exit", -1) == 0
            stdout = Ops.get_string(rmap, "stdout", "")
            stdout = String.CutBlanks(stdout)
            stdout = NovellUtils.StripTrailing(stdout, "\n")
            Builtins.y2milestone("value of stdout is %1", stdout)
            return stdout
          else
            return ""
          end
        end
      else
        Builtins.y2milestone("Skipping DNS resolution for the local hostname: %1", dbHostName)
      end
      return ""
    end

    def isLocalServer?(dbHostName)
      dbHostName == "localhost" || dbHostName == NovellUtils.GetDNSname || dbHostName == NovellUtils.GetHostname
    end

    def isRemoteServer?(dbHostName)
      dbHostName != "localhost" && dbHostName != NovellUtils.GetDNSname && dbHostName != NovellUtils.GetHostname
    end

  end
end
