# encoding: utf-8

# *****************************************************************************
#
# (c) Copyright 2022 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its
# affiliates and licensors(Micro Focus) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional warranty.
# Micro Focus shall not be liable for technical or editorial errors or
# omissions contained herein.
# The information contained herein is subject to change without notice.
#
# ******************************************************************************
# File:        include/umc/wizard.rb
# Module:      Installation
# Summary:     Wizards definitions
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#              Srinidhi B <Srinidhi.BS@microfocus.com>
#

module Yast
  module UmcWizardsInclude
    def initialize_umc_wizards(include_target)
      Yast.import "UI"

      textdomain "umc"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "umc/complex.rb"
      Yast.include include_target, "umc/dialogs.rb"
    end

    # Main workflow of the UMC configuration
    # @return sequence result
    def MainSequence
      aliases = { "umcDialog" => lambda { UmcDialog() } }

      sequence = {
        "ws_start" => "umcDialog",
        "umcDialog" => { :abort => :abort, :next => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of umc
    # @return sequence result
    def UmcSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("umc")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of umc but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def UmcAutoSequence
      # Initialization dialog caption
      caption = _("UMC Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("umc")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
